==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/QueryNonExistant.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
using com.db4o.query;
namespace com.db4o.test {

   public class QueryNonExistant {
      internal QueryNonExistant1 member;
      
      public QueryNonExistant() : base() {
      }
      
      public QueryNonExistant(bool createMembers) : base() {
         member = new QueryNonExistant1();
         member.member = new QueryNonExistant2();
         member.member.member = this;
      }
      
      public void test() {
         ObjectContainer con1 = Tester.objectContainer();
         con1.get(new QueryNonExistant(true));
         Tester.ensureOccurrences(new QueryNonExistant(), 0);
         Query q1 = con1.query();
         q1.constrain(new QueryNonExistant(true));
         Tester.ensure(q1.execute().size() == 0);
      }
      
      public class QueryNonExistant1 {
         
         public QueryNonExistant1() : base() {
         }
         internal QueryNonExistant2 member;
      }
      
      public class QueryNonExistant2 : QueryNonExistant1 {
         
         public QueryNonExistant2() : base() {
         }
         internal QueryNonExistant member;
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/QueryNonExistant.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
using com.db4o.query;
namespace com.db4o.test {

   public class QueryNonExistant {
      internal QueryNonExistant1 member;
      
      public QueryNonExistant() : base() {
      }
      
      public QueryNonExistant(bool createMembers) : base() {
         member = new QueryNonExistant1();
         member.member = new QueryNonExistant2();
         member.member.member = this;
      }
      
      public void Test() {
         ObjectContainer con1 = Tester.ObjectContainer();
         con1.Get(new QueryNonExistant(true));
         Tester.EnsureOccurrences(new QueryNonExistant(), 0);
         Query q1 = con1.Query();
         q1.Constrain(new QueryNonExistant(true));
         Tester.Ensure(q1.Execute().Size() == 0);
      }
      
      public class QueryNonExistant1 {
         
         public QueryNonExistant1() : base() {
         }
         internal QueryNonExistant2 member;
      }
      
      public class QueryNonExistant2 : QueryNonExistant1 {
         
         public QueryNonExistant2() : base() {
         }
         internal QueryNonExistant member;
      }
   }
}
